@@ -1,5 +1,5 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-// Copyright (C) 2006-2010 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -629,7 +629,7 @@ int MutexCounter::operator--()
         rtn = --counter;
         if(!rtn) {
             leaveMutex();
-            THROW(mc);
+            THROW(counter);
         }
     }
     leaveMutex();
