@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2010 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
 //
 // This file is part of GNU uCommon C++.
 //
@@ -31,11 +31,11 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef  NEW_STDLIB
+#ifdef  NEW_STDCPP
 #include <stdexcept>
 #endif
 
-#if defined(NEW_STDLIB) || defined(OLD_STDLIB)
+#if defined(NEW_STDCPP) || defined(OLD_STDCPP)
 #define THROW(x)    throw x
 #define THROWS(x)   throw(x)
 #define THROWS_ANY  throw()
